@@ -19,10 +19,18 @@ pixel_width = 16
 pixel_height = 16
 
 pixels = neopixel.NeoPixel(
-    pixel_pin, pixel_width * pixel_height, brightness=0.1, auto_write=False,
+    pixel_pin,
+    pixel_width * pixel_height,
+    brightness=0.1,
+    auto_write=False,
 )
 
-pixel_framebuf = PixelFramebuffer(pixels, pixel_width, pixel_height, reverse_x=True,)
+pixel_framebuf = PixelFramebuffer(
+    pixels,
+    pixel_width,
+    pixel_height,
+    reverse_x=True,
+)
 
 # Make a black background in RGBA Mode
 image = Image.new("RGBA", (pixel_width, pixel_height))
